==> jc-1.4.0.tar.gz: soot/jimple/internal/JLtExpr.h <==
// public class soot.jimple.internal.JLtExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class f9eab9f2510f54c9 soot_jimple_internal_AbstractIntBinopExpr
// @dep_class 742ef0012b237efb soot_jimple_internal_AbstractJimpleIntBinopExpr
// @dep_class e508a313d28d5813 soot_jimple_internal_JLtExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractJimpleIntBinopExpr

#include "soot/jimple/internal/AbstractJimpleIntBinopExpr.h"

#ifndef _JC_soot_jimple_internal_JLtExpr_H_
#define _JC_soot_jimple_internal_JLtExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JLtExpr$sub_refs	_jc_soot_jimple_internal_JLtExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JLtExpr$sub_nonrefs	_jc_soot_jimple_internal_JLtExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JLtExpr$refs	_jc_soot_jimple_internal_JLtExpr$refs;
typedef struct _jc_soot_jimple_internal_JLtExpr$nonrefs	_jc_soot_jimple_internal_JLtExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JLtExpr$object	_jc_soot_jimple_internal_JLtExpr$object;

typedef const struct _jc_soot_jimple_internal_JLtExpr$vmethods	_jc_soot_jimple_internal_JLtExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JLtExpr$vtable	_jc_soot_jimple_internal_JLtExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JLtExpr$vtype	_jc_soot_jimple_internal_JLtExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JLtExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_internal_JLtExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JLtExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JLtExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JLtExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JLtExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JLtExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JLtExpr$method_info$getSymbol$ce407d9fb7da8b41;
extern _jc_method _jc_soot_jimple_internal_JLtExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_JLtExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *);
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *);
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JLtExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntBinopExpr$vmethods	soot_jimple_internal_AbstractIntBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleIntBinopExpr;
	_jc_soot_jimple_internal_JLtExpr$vmethods	soot_jimple_internal_JLtExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JLtExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JLtExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JLtExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JLtExpr$refs {
    _jc_soot_jimple_internal_JLtExpr$sub_refs	soot_jimple_internal_JLtExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleIntBinopExpr;
    _jc_soot_jimple_internal_AbstractIntBinopExpr$sub_refs	soot_jimple_internal_AbstractIntBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JLtExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JLtExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleIntBinopExpr;
    _jc_soot_jimple_internal_JLtExpr$sub_nonrefs	soot_jimple_internal_JLtExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JLtExpr$object {
	_jc_soot_jimple_internal_JLtExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JLtExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JLtExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JLtExpr$vtype _jc_soot_jimple_internal_JLtExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JLtExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JLtExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JLtExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JLtExpr.h <==
// public class soot.jimple.internal.JLtExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class f9eab9f2510f54c9 soot_jimple_internal_AbstractIntBinopExpr
// @dep_class 742ef0012b237efb soot_jimple_internal_AbstractJimpleIntBinopExpr
// @dep_class e508a313d28d5813 soot_jimple_internal_JLtExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractJimpleIntBinopExpr

#include "soot/jimple/internal/AbstractJimpleIntBinopExpr.h"

#ifndef _JC_soot_jimple_internal_JLtExpr_H_
#define _JC_soot_jimple_internal_JLtExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JLtExpr$sub_refs	_jc_soot_jimple_internal_JLtExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JLtExpr$sub_nonrefs	_jc_soot_jimple_internal_JLtExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JLtExpr$refs	_jc_soot_jimple_internal_JLtExpr$refs;
typedef struct _jc_soot_jimple_internal_JLtExpr$nonrefs	_jc_soot_jimple_internal_JLtExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JLtExpr$object	_jc_soot_jimple_internal_JLtExpr$object;

typedef const struct _jc_soot_jimple_internal_JLtExpr$vmethods	_jc_soot_jimple_internal_JLtExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JLtExpr$vtable	_jc_soot_jimple_internal_JLtExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JLtExpr$vtype	_jc_soot_jimple_internal_JLtExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JLtExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_internal_JLtExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JLtExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JLtExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JLtExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JLtExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JLtExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JLtExpr$method_info$getSymbol$ce407d9fb7da8b41;
extern _jc_method _jc_soot_jimple_internal_JLtExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_JLtExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_JLtExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JLtExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntBinopExpr$vmethods	soot_jimple_internal_AbstractIntBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleIntBinopExpr;
	_jc_soot_jimple_internal_JLtExpr$vmethods	soot_jimple_internal_JLtExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JLtExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JLtExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JLtExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JLtExpr$refs {
    _jc_soot_jimple_internal_JLtExpr$sub_refs	soot_jimple_internal_JLtExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleIntBinopExpr;
    _jc_soot_jimple_internal_AbstractIntBinopExpr$sub_refs	soot_jimple_internal_AbstractIntBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JLtExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JLtExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleIntBinopExpr;
    _jc_soot_jimple_internal_JLtExpr$sub_nonrefs	soot_jimple_internal_JLtExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JLtExpr$object {
	_jc_soot_jimple_internal_JLtExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JLtExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JLtExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JLtExpr$vtype _jc_soot_jimple_internal_JLtExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JLtExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JLtExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JLtExpr_H_ */
